<?php
/**
 * Customizer Data importer class.
 *
 * @since  2.0.0
 * @package WPZOOM
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Customizer Data importer class.
 *
 * @since  2.0.0
 */
class WPZOOM_Customizer_Import {

	/**
	 * Instance of WPZOOM_Customizer_Import
	 *
	 * @since  2.0.0
	 * @var WPZOOM_Customizer_Import
	 */
	private static $instance = null;

	/**
	 * Instantiate WPZOOM_Customizer_Import
	 *
	 * @since  2.0.0
	 * @return (Object) WPZOOM_Customizer_Import
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Import customizer options.
	 *
	 * @since  2.0.0
	 *
	 * @param  (Array) $options customizer options from the demo.
	 */
	public function import( $options ) {

		// Update Theme customizer settings.
		if ( isset( $options['wpzoom-settings'] ) ) {
			self::import_settings( $options['wpzoom-settings'] );
		}

		// Add Custom CSS.
		if ( isset( $options['custom-css'] ) ) {
			wp_update_custom_css_post( $options['custom-css'] );
		}
	}

	/**
	 * Import Theme Setting's
	 *
	 * Download & Import images from Theme Customizer Settings.
	 *
	 * @since 2.0.0
	 *
	 * @param  array $options Theme Customizer setting array.
	 * @return void
	 */
	public static function import_settings( $options = array() ) {
		array_walk_recursive(
			$options,
			function ( &$value ) {
				if ( ! is_array( $value ) && zoom_is_valid_image( $value ) ) {
					$downloaded_image = WPZOOM_Demo_Image_Importer::get_instance()->import(
						array(
							'url' => $value,
							'id'  => 0,
						)
					);
					$value            = $downloaded_image['url'];
				}
			}
		);

		// Updated settings.
		update_option( 'wpzoom-settings', $options );
	}
}
